@@ -17,7 +17,6 @@
 
 import gtk
 import gobject
-import gnome
 import gu
 
 import mpd
@@ -29,12 +28,12 @@ import cfg
 import dataparser
 import soundcard
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
     #UGH should we do this here
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.ChordLessonfile
     def new_question(self):
         """
@@ -105,17 +104,17 @@ class Gui(abstract.LessonbasedGui):
         ###############
         # practise_box
         ###############
-        self.practise_box.set_spacing(gnome.ui.PAD)
+        self.practise_box.set_spacing(gu.PAD)
 
         hbox = gu.bHBox(self.practise_box, True, True)
-        hbox.set_spacing(gnome.ui.PAD)
+        hbox.set_spacing(gu.PAD)
         ##################
         # chordtype frame 
         ##################
         frame = gtk.Frame(_("Identify chord type"))
         hbox.pack_start(frame)
         self.g_chordtype_box = gtk.VBox()
-        self.g_chordtype_box.set_border_width(gnome.ui.PAD_SMALL)
+        self.g_chordtype_box.set_border_width(gu.PAD_SMALL)
         frame.add(self.g_chordtype_box)
 
         #################
@@ -125,7 +124,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_stacking_frame.set_sensitive(False)
         hbox.pack_start(self.g_stacking_frame)
         vbox = gtk.VBox()
-        vbox.set_border_width(gnome.ui.PAD_SMALL)
+        vbox.set_border_width(gu.PAD_SMALL)
         self.g_stacking_frame.add(vbox)
         t = gtk.Table(1, 1, 1)
         vbox.pack_start(t)
@@ -150,7 +149,7 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.config_box.set_spacing(gnome.ui.PAD_SMALL)
+        self.config_box.set_spacing(gu.PAD_SMALL)
         self.add_random_transpose_gui()
     def new_question(self, widget=None):
         def exception_cleanup():
