@@ -280,6 +280,7 @@ class Dataparser:
         # for example self.blocklists['element'] = []
         self.blocklists = {}
         self.context = self.globals
+        self.m_ignore_lookup_error = False
     def parse_file(self, filename):
         """We always construct a new parser if we want to parse another
         file. So this method is never called twice for one parser.
@@ -290,6 +291,11 @@ class Dataparser:
         infile.close()
         self.reserved_words = ('_', 'question', 'header')
         self.prog()
+    def parse_string(self, s):
+        self.m_filename = "<STRING>"
+        self._lexer = Lexer(s, self)
+        self.reserved_words = ('_', 'question', 'header')
+        self.prog()
     def prog(self):
         """prog: statementlist EOF"""
         self.statementlist()
@@ -483,6 +489,8 @@ class Dataparser:
         elif name in self.globals:
             return self.globals[name]
         else:
+            if self.m_ignore_lookup_error:
+                return "LOOKUP IGNORED"
             raise NameLookupException(name, self)
 
 
