@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2005 Tom Cato Amundsen
+# Copyright (C) 2005, 2006 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@ import i18n
 from htmlwidget import HtmlWidget
 
 class DocViewer(gtk.VBox):
+    """
+    The purpose of this class is to:
+        - provide the status bar
+        - select the correct translation of a document
+    """
     def __init__(self, activate_cb):
         gtk.VBox.__init__(self)
         self.m_htmlwidget = HtmlWidget(activate_cb, self.on_anchor_track)
@@ -42,12 +47,26 @@ class DocViewer(gtk.VBox):
         self.m_htmlwidget.m_document_wd = os.path.join("help", self.m_language)
     def read_docfile(self, fn, anchor):
         """
-        We reread the docfile even if we are alreado displaying this file,
-        just in case it has changed on disk.t
+        We reread the docfile even if we are already displaying this file,
+        just in case it has changed on disk.
+
+        fn is one of two:
+        1. A absolute path to a file that we should read. Display 'File
+           not found' if exactly this file is not found.
+        2. Relative path to a file relative to the file currently displayed
+           in m_htmlwidget.
+
+        Set self.m_loaded_file.
         """
         try:
             if fn:
-                self.m_htmlwidget.source(open(os.path.join("help", self.m_language, fn), 'r').read())
+                if os.path.isabs(fn):
+                    self.m_htmlwidget.read_file_abs(fn)
+                else:
+                    if not os.path.exists(os.path.join(self.m_htmlwidget.m_document_wd, fn)):
+                        fn = os.path.normpath(os.path.join("../C", fn))
+                    self.m_htmlwidget.read_file_rel(fn)
+                self.m_loaded_file = fn
             if anchor and 'g_view' in dir(self.m_htmlwidget):
                 self.m_htmlwidget.g_view.jump_to_anchor(anchor)
         except IOError, e:
