@@ -132,7 +132,7 @@ class Gui(abstract.LessonbasedGui):
         #if 'show' in self.m_t.m_P.header.at_question_start \
         #    and 'play' in self.m_t.m_P.header.at_question_start:
         if self.m_t.m_P.header.have_music_displayer:
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
         try:
             self.do_at_question_start_show_play()
         except Exception, e:
@@ -234,9 +234,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_answer_button_box.empty()
         self.g_answer.foreach(lambda w: w.destroy())
         #
+        if not self.m_t.m_P.header.music_displayer_stafflines:
+            self.m_t.m_P.header.music_displayer_stafflines = 1
+        #
         if self.m_t.m_P.header.have_music_displayer:
             self.g_music_displayer.show()
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
         else:
             self.g_music_displayer.hide()
         #
