@@ -13,6 +13,14 @@ class Path(tuple):
         v = list(self)
         v[-1] -= 1
         return Path(v)
+    def child(self):
+        v = list(self)
+        v.append(0)
+        return Path(v)
+    def parent(self):
+        v = list(self)
+        v = v[:-1]
+        return Path(v)
 
 class TestPath(unittest.TestCase):
     def test_next(self):
@@ -21,6 +29,12 @@ class TestPath(unittest.TestCase):
     def test_prev(self):
         p = Path((1, 2, 3))
         self.assert_(p.prev(), (1, 2, 2))
+    def test_child(self):
+        p = Path((1, 2, 3))
+        self.assert_(p.child(), (1, 2, 3, 0))
+    def test_parent(self):
+        p = Path((1, 2, 3))
+        self.assert_(p.parent(), (1, 2))
 
 
 if __name__ == '__main__':
