@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -50,6 +50,11 @@ def startswith_whitespace(s):
 def endswith_whitespace(s):
     return not s == s.rstrip()
 
+def url_decode(url):
+    def repf(s):
+            return chr(int(s.group()[1:], 16))
+    return re.sub("%[0-9A-F][0-9A-F]", repf, url)
+
 class _HtmlWidgetCommon(object):
     def __init__(self):
         self.m_document_wd = None
@@ -66,25 +71,6 @@ class _HtmlWidgetCommon(object):
         fn = os.path.join(self.m_document_wd, filename)
         self.m_document_wd = os.path.dirname(fn)
         self.source(file(fn, 'r').read())
-    def read_docfile(self, filename, locale=None):
-        filefound = None
-        if locale:
-            languages = [locale]
-        else:
-            languages = i18n.langs()
-        for lang in languages:
-            if os.path.isfile(os.path.join('online-docs', lang, filename)):
-                head, tail = os.path.split(filename)
-                self.m_document_wd = os.path.join("online-docs", lang, head)
-                self.source(open(os.path.join("online-docs", lang, filename), 'r').read())
-                filefound = 1
-                break
-        if not filefound:
-            for lang in languages:
-                fn = os.path.join('online-docs', lang, 'missing-helpfile.html')
-                if os.path.isfile(fn):
-                    self.source(open(fn, 'r').read())
-                    break
 
 
 class GtkHtml2Widget(gtk.ScrolledWindow, _HtmlWidgetCommon):
@@ -114,6 +100,7 @@ class GtkHtml2Widget(gtk.ScrolledWindow, _HtmlWidgetCommon):
         #if url == "style.css":
         #    stream.set_mime_type("text/css")
         #    print stream.get_mime_type()
+        url = url_decode(url)
         try:
             s = open(os.path.join(self.m_document_wd, url), 'r').read()
             stream.write(s)
@@ -147,12 +134,20 @@ class MyTextView(gtk.TextView):
         self.connect("event-after", self.on_event_after)
         self.connect("motion-notify-event", self.on_motion_notify_event)
         def rr(widget):
-            width = widget.get_data('html-percentage-width')
+            width = widget.get_data('html-cell-width')
+            parent_w = widget.get_parent().get_parent().get_allocation().width - self.m_margin * 2
             if width:
-                # The text view is inside a table, since only those has the
-                # data variable 'html-percentage-width' set.
-                parent_w = widget.get_parent().get_parent().get_allocation().width - self.m_margin * 2
-                widget.set_size_request(parent_w * width / 100, -1)
+                try:
+                    # The text view is inside a table, since only those has the
+                    # data variable 'html-percentage-width' set.
+                    if width.endswith('%'):
+                        width = int(float(width[:-1]))
+                        widget.set_size_request(parent_w * width / 100, -1)
+                    else:
+                        width = int(float(width))
+                        widget.set_size_request(width, -1)
+                except ValueError:
+                    pass
             rect = widget.get_allocation()
         self.connect("realize", rr)
         self.set_wrap_mode(gtk.WRAP_WORD)
@@ -279,6 +274,12 @@ class ElementBaseClass(tree.TreeNode):
         v = [x for x in self.m_attrs if x[0] == name]
         if v:
             return v[0][1]
+    def set_attr(self, attrname, value):
+        for idx, name in enumerate(self.m_attrs):
+            if name == attrname:
+                self.m_attrs[idx] = value
+                return
+        self.m_attrs.append((attrname, value))
     def show_children(self, level):
         print "    " * level, self, self.m_first, self.m_last
         for n in self.m_children:
@@ -412,7 +413,7 @@ class IMG(Inline):
     def write_to_buffer(self, buffer, textview, document_wd):
         anchor = buffer.create_child_anchor(buffer.get_end_iter())
         im = gtk.Image()
-        im.set_from_file(os.path.join(document_wd, self.get_attr("src")))
+        im.set_from_file(os.path.join(document_wd, url_decode(self.get_attr("src"))))
         im.show()
         textview.add_child_at_anchor(im, anchor)
     def calc_bounds(self, idx):
@@ -432,11 +433,23 @@ class Table(Block):
     def write_to_buffer(self, buffer, textview, document_wd):
         anchor = buffer.create_child_anchor(buffer.get_end_iter())
         t = gtk.Table()
+        t.set_homogeneous(False)
+        for rownum, row in enumerate(self.m_rows):
+            for cell in row:
+                if not cell.get_attr('width'):
+                    # If the only content of the cell (TD) is a image,
+                    # then we set the with of the TextView that is holding
+                    # the content of the cell to the width of the image.
+                    # FIXME: if this is the case, then we really should just
+                    # put an image in the GtkTable and not a TextView.
+                    if len(cell.m_children) == 1:
+                        w = cell.m_children[0].get_attr('width')
+                        if w:
+                            cell.set_attr('width', w)
         for rownum, row in enumerate(self.m_rows):
             for cellnum, cell in enumerate(row):
                 cell_buf = gtk.TextBuffer()
                 cell_tw = MyTextView(cell_buf)
-                cell_tw.set_size_request(200, -1)
                 cell_tw.set_wrap_mode(gtk.WRAP_WORD)
                 cell_tw.root_widget = textview.root_widget
                 cell_tw.setup_tags()
@@ -444,9 +457,7 @@ class Table(Block):
                     cell.m_extra_tags.append('center')
                 width = cell.get_attr('width')
                 if width:
-                    if width.endswith('%'):
-                        width = int(width[:-1]) # FIXME catch exception
-                    cell_tw.set_data('html-percentage-width', width)
+                    cell_tw.set_data('html-cell-width', width)
                 cell.calc_bounds(0)
                 #FIXME print "Fjern?"
                 for c in cell.m_children:
