@@ -60,12 +60,15 @@ def langs():
 
 def setup(prefix, config_locale=None):
     # Gettext and gtk+ chech the variables in this order.
-    varlist = ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG')
+    locale.setlocale(locale.LC_ALL, '')
+    varlist = ('LANGUAGE', 'LC_MESSAGES')
     if not config_locale:
         config_locale = 'system default'
     if config_locale != 'system default':
         for n in varlist:
             os.environ[n] = config_locale
+    # FIXME can we remove this whole if block, not that set run
+    # locale.setlocale(locale.LC_ALL, '') at program start??
     if (sys.platform == 'win32') and (config_locale == 'system default'):
         envar = None
         for varname in varlist:
