@@ -15,14 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gnome, gtk, gobject
+import gtk, gobject
 import soundcard
 import abstract, const, statistics, statisticsviewer, gu, random
 import lessonfile
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
         # 60, 84, 100, 120
         self.m_ped = [60, 120, 40, 168, 208, 80, 96, 139, 48, 69, 108, 192, 152,
@@ -104,7 +104,7 @@ class Gui(abstract.Gui):
         ################
         # practise_box #
         ################
-        self.practise_box.set_spacing(gnome.ui.PAD)
+        self.practise_box.set_spacing(gu.PAD)
         self.m_buttons = []
         vbox = gu.bVBox(self.practise_box, False)
         for s, e in ((0, 9), (9, 18), (18, 26), (26, 34)):
