@@ -20,14 +20,7 @@ from __future__ import division
 if __name__ == '__main__':
     import testsetup
 
-import gtk, gnome.ui
-try:
-    import gnomecanvas
-    canvasmodule = gnomecanvas
-except ImportError:
-    import gnome.canvas
-    canvasmodule = gnome.canvas
-
+import gtk
 import runtime
 if runtime.use_cairo_widgets:
     import math
