@@ -29,6 +29,7 @@ import cfg
 import gu
 import lessonfilegui
 from gpath import Path
+import gethomedir
 
 class Menu(dict):
     def new_from_name(name):
@@ -70,6 +71,7 @@ class LearningTree:
         self.lessonfile_manager = lessonfile_manager
         self.m_menus = []
         self.m_deps = {}
+        self.m_modified = False
     def load(self, filename):
         self.m_visibility = 0
         self.m_learning_tree_version = 0
@@ -117,6 +119,7 @@ class LearningTree:
                         self.m_deps[d].remove(j)
         self.sort_topics()
         self.calculate_visibilities()
+        self.m_modified = False
     def save(self, filename):
         ofile = file(filename, 'w')
         print >> ofile, "[ # toplevel list"
@@ -127,11 +130,14 @@ class LearningTree:
         print >> ofile, "  ], # end of list of menus"
         ofile.write("%s,\n%s]" % (pprint.pformat(self.m_deps), self.m_visibility))
         ofile.close()
+        self.m_modified = False
     def new_menu(self, menuname):
         self.m_menus.append(Menu({'name': menuname, 'children': []}))
+        self.m_modified = True
     def new_topic(self, menu_idx, topicname):
         assert topicname not in [s.name for s in self.m_menus[menu_idx].children]
         self.m_menus[menu_idx].children.append(Menu.new_from_name(topicname))
+        self.m_modified = True
     def sort_topics(self):
         """
         Sort the lessons in each topic.
@@ -154,6 +160,7 @@ class LearningTree:
                 self.get(p).children[path[-1]-1], self.get(p).children[path[-1]]
         except IndexError:
             return False
+        self.m_modified = True
         return True
     def move_elem_to_prev_menu(self, path):
         """
@@ -166,6 +173,7 @@ class LearningTree:
         to_path = tuple(to_path)
         self.get(to_path).children.append(self.get(path))
         del self.get(path[:-1]).children[path[-1]]
+        self.m_modified = True
         return to_path + (len(self.get(to_path).children)-1,)
     def move_elem_down(self, path):
         """
@@ -181,6 +189,7 @@ class LearningTree:
                     self.get(p).children[path[-1]]
         except IndexError:
             return False
+        self.m_modified = True
         return True
     def move_elem_to_next_menu(self, path):
         """
@@ -194,6 +203,7 @@ class LearningTree:
         pn = tuple(pn)
         self.get(pn).children.insert(0, self.get(path))
         del self.get(path[:-1]).children[path[-1]]
+        self.m_modified = True
         return pn + (0,)
     def move_lesson_up(self, path):
         """
@@ -207,6 +217,7 @@ class LearningTree:
         prev_id = self.get(Path(path).prev())
         if prev_id not in list(self.iter_subdeps(move_id)):
             self.move_elem_up(path)
+            self.m_modified = True
             return True
         return False
     def move_lesson_down(self, path):
@@ -224,6 +235,7 @@ class LearningTree:
                     self.get(p).children[i + 1], self.get(p).children[i]
             except IndexError:
                 return False
+            self.m_modified = True
             return True
         return False
     def add_lesson(self, path, lesson_id):
@@ -239,17 +251,22 @@ class LearningTree:
             menu.children.sort(lambda a, b: self.cmp(a, b))
         else:
             return False
+        self.m_modified = True
+        return True
     def delete_lesson(self, path):
         menu = self.get(path[:-1])
         del menu.children[path[-1]]
+        self.m_modified = True
     def add_dependency(self, lesson_id, dep_id):
         assert dep_id not in self.m_deps[lesson_id]
         self.m_deps[lesson_id].append(dep_id)
         self.sort_topics()
+        self.m_modified = True
     def delete_dependency(self, lesson_id, id_to_delete):
         i = self.m_deps[lesson_id].index(id_to_delete)
         del self.m_deps[lesson_id][i]
         self.sort_topics()
+        self.m_modified = True
     def iterate_all_lessons2(self):
         """
         Iterate all lessons that are added to the learning tree.
@@ -400,6 +417,7 @@ class LearningTree:
         for v in self.m_deps.values():
             if del_id in v:
                 del v[v.index(del_id)]
+        self.m_modified = True
     def get(self, path):
         """
         Return the element pointed to by path.
@@ -535,15 +553,30 @@ class Window(gtk.Window):
         self.add(self.vbox)
         hbox = gtk.HBox()
         self.vbox.pack_start(hbox, False)
-        g = gtk.Button(_("Save"))
+        g = gtk.Button(stock='gtk-new')
+        g.connect('clicked', self.on_new)
+        hbox.pack_start(g, False)
+        g = gtk.Button(stock='gtk-save')
         g.connect('clicked', self.on_save)
         hbox.pack_start(g, False)
-        g = gtk.Button(_("Save as..."))
+        g = gtk.Button(stock='gtk-save-as')
         g.connect('clicked', self.on_save_as)
         hbox.pack_start(g, False)
-        g = gtk.Button(_("Close"))
+        g = gtk.Button(stock='gtk-close')
         g.connect('clicked', self.close_window)
         hbox.pack_start(g, False)
+        hbox = gtk.HBox()
+        self.vbox.pack_start(hbox, False)
+        gu.bLabel(hbox, _("Learning tree:"), False, False)
+        self.g_trees_liststore = gtk.ListStore(gobject.TYPE_STRING)
+        self.g_trees = gtk.ComboBox(self.g_trees_liststore)
+        cell = gtk.CellRendererText()
+        self.g_trees.pack_start(cell, True)
+        self.g_trees.add_attribute(cell, 'text', 0)
+        self.g_trees.connect('changed', self.on_learning_tree_combo_changed)
+        self.fill_trees_combo()
+        hbox.pack_start(self.g_trees)
+        self.g_trees.show()
         #######################
         self.g_content_vbox = gtk.VBox()
         self.vbox.pack_start(self.g_content_vbox)
@@ -659,9 +692,41 @@ class Window(gtk.Window):
         self.g_deps.set_model(self.g_deps_liststore)
         ###
         self.connect('delete_event', self.on_delete_event)
-        self.m_changed = False
+        self.m_modified = False
         self.show_all()
         self.treeview_cursor_changed()
+        self.__load_file2_lock = 0
+    def fill_trees_combo(self):
+        self.m_trees = [('solfege', 'learningtree.txt', os.path.join(os.getcwd(), 'learningtree.txt'))]
+        try:
+            v = os.listdir(os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees"))
+        except OSError:
+            v = []
+        for fn in v:
+            self.m_trees.append(('user', fn, os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees", fn)))
+        self.g_trees_liststore.clear()
+        for t, fn, txt in self.m_trees:
+            self.g_trees_liststore.append((txt,))#_text(txt)
+    def set_trees_combo(self, place, filename):
+        # Set the combo to the correct learning tree.
+        self.__load_file2_lock += 1
+        idx = 0
+        while idx < len(self.m_trees):
+            if self.m_trees[idx][0] == place \
+                    and self.m_trees[idx][1] == filename:
+                self.g_trees.set_active(idx)
+            idx += 1
+        self.__load_file2_lock -= 1
+    def on_learning_tree_combo_changed(self, combobox):
+        t, fn, txt = self.m_trees[combobox.get_active()]
+        if self.m_tree.m_modified:
+            if gu.dialog_yesno(_("The file is not saved. Save before changing?"), self):
+                self._do_save(self.m_filename)
+        if not self.__load_file2_lock:
+            self.load_file2(t, fn)
+        self.treeview_cursor_changed()
+        cfg.set_list('app/learningtree', [t, fn])
+        self.m_app.m_ui.on_learning_tree_changed()
     def treeview_cursor_changed(self, w=None):
         path = self.g_treeview.get_cursor()[0]
         self.g_new_submenu.set_sensitive(path is not None and len(path) < 2)
@@ -712,6 +777,61 @@ class Window(gtk.Window):
                         self.m_model.set(child_iter, 0, self.m_app.lessonfile_manager.get(child, 'title'), 1, _("Lesson"))
             create_for_children(menu, None)
         self.g_treeview.set_model(self.m_model)
+    def on_new(self, widget):
+        dlg = gtk.Dialog(_("Create new learning tree"), self, buttons=
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+            gtk.STOCK_OK, gtk.RESPONSE_OK))
+        dlg.set_default_response(gtk.RESPONSE_OK)
+        vbox = gtk.VBox()
+        dlg.vbox.pack_start(vbox)
+        vbox.set_border_width(18)
+        self.g_heading = gtk.Label("<b>%s</b>" % _("Create new learning tree"))
+        self.g_heading.set_alignment(0.0, 0.5)
+        vbox.pack_start(self.g_heading, False)
+        hbox = gtk.HBox()
+        hbox.set_spacing(12)
+        vbox.pack_start(hbox, False)
+        self.g_heading.set_use_markup(True)
+        self.g_filename_description = gtk.Label(_("Do not enter any directory names, only the filename."))
+        self.g_message = gtk.Label(_("File name:"))
+        self.g_entry = gtk.Entry()
+        self.g_entry.set_activates_default(True)
+        hbox.pack_start(self.g_message, False)
+        hbox.pack_start(self.g_entry, False)
+        dlg.show_all()
+        vbox.pack_start(self.g_filename_description, False)
+        while 1:
+            ret = dlg.run()
+            if ret == gtk.RESPONSE_OK:
+                path, filename = os.path.split(self.g_entry.get_text())
+                if path or (not filename):
+                    self.g_filename_description.set_text(_("Enter a file name with no directory."))
+                    self.g_filename_description.show()
+                elif os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename)):
+                    self.g_filename_description.set_text(_("The file already exists."))
+                    self.g_filename_description.show()
+                else:
+                    try:
+                        f = file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename), 'w')
+                        f.write("""
+[ # toplevel list
+  2, # learning tree file format version
+  [ # start of list of menus
+  ], # end of list of menus
+{},
+100]
+""")
+                        f.close()
+                        self.fill_trees_combo()
+                        self.load_file2('user', filename)
+                        cfg.set_list('app/learningtree', ['user', filename])
+                        self.m_app.m_ui.on_learning_tree_changed()
+                    except IOError, e:
+                        gu.dialog_ok(_("An error occurred while saving the file:\n%s") % e, self)
+                    break
+            if ret == gtk.RESPONSE_CANCEL:
+                break
+        dlg.destroy()
     def on_delete_event(self, *v):
         self.close_window()
     def close_window(self, *v):
@@ -826,12 +946,26 @@ class Window(gtk.Window):
         hbox.pack_start(self.g_message, False)
         hbox.pack_start(self.g_entry, False)
         dlg.show_all()
-        ret = dlg.run()
+        self.g_explain = gtk.Label()
+        vbox.pack_start(self.g_explain, False)
+        while 1:
+            ret = dlg.run()
+            if ret == gtk.RESPONSE_OK:
+                n = self.g_entry.get_text()
+                if n in [s['name'] for s in self.m_tree.m_menus]:
+                    self.g_explain.set_text(_("The menu name is already used."))
+
+                    self.g_explain.show()
+                elif not n:
+                    self.g_explain.set_text(_("An empty string is not allowed."))
+                    self.g_explain.show()
+                else:
+                    self.m_tree.new_menu(n)
+                    self.m_model.append(None, (n, _("Menu")))
+                    break
+            elif ret == gtk.RESPONSE_CANCEL:
+                break
         dlg.destroy()
-        if ret == gtk.RESPONSE_OK:
-            n = self.g_entry.get_text()
-            self.m_tree.new_menu(n)
-            self.m_model.append(None, (n, _("Menu")))
     def on_new_topic(self, *v):
         menu_idx = self.g_treeview.get_cursor()[0][0]
         dlg = gtk.Dialog(_("New topic"), self, buttons=
@@ -854,16 +988,29 @@ class Window(gtk.Window):
         hbox.pack_start(self.g_message, False)
         hbox.pack_start(self.g_entry, False)
         dlg.show_all()
-        ret = dlg.run()
+        self.g_explain = gtk.Label()
+        vbox.pack_start(self.g_explain, False)
+        while 1:
+            ret = dlg.run()
+            if ret == gtk.RESPONSE_OK:
+                n = self.g_entry.get_text()
+                if not n:
+                    self.g_explain.set_text(_("An empty string is not allowed."))
+                    self.g_explain.show()
+                elif n in [c['name'] for c in self.m_tree.m_menus[menu_idx]['children']]:
+                    self.g_explain.set_text(_("The menu name is already used."))
+
+                    self.g_explain.show()
+                else:
+                    self.m_tree.new_topic(menu_idx, n)
+                    iter = self.m_model.iter_nth_child(None, menu_idx)
+                    new_iter = self.m_model.append(iter, (n, _("Submenu")))
+                    self.g_treeview.expand_to_path(self.m_model.get_path(new_iter))
+                    self.g_treeview.set_cursor(self.m_model.get_path(new_iter))
+                    break
+            elif ret == gtk.RESPONSE_CANCEL:
+                break
         dlg.destroy()
-        if ret == gtk.RESPONSE_OK:
-            n = self.g_entry.get_text()
-            if n:
-                self.m_tree.new_topic(menu_idx, n)
-                iter = self.m_model.iter_nth_child(None, menu_idx)
-                new_iter = self.m_model.append(iter, (n, _("Submenu")))
-                self.g_treeview.expand_to_path(self.m_model.get_path(new_iter))
-                self.g_treeview.set_cursor(self.m_model.get_path(new_iter))
     def on_move_topic_up(self, *v):
         path = self.g_treeview.get_cursor()[0]
         if path[-1] > 0:
@@ -1016,7 +1163,26 @@ class Window(gtk.Window):
             iter = self.m_model.get_iter(path)
             self.m_model.swap(iter, self.m_model.get_iter(next_path))
             self.g_treeview.scroll_to_cell(next_path)
-    def load_file(self, filename):
+    def load_file2(self, place, filename):
+        """
+        place is 'solfege' or 'user'
+        filename is a filename, with no directory part.
+        This function will also make sure the g_trees combo is set.
+        """
+        if place == 'solfege':
+            self._load_file(filename)
+        else:
+            assert place == 'user'
+            self._load_file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
+        self.set_trees_combo(place, filename)
+        # 
+        if place == 'solfege':
+            if not os.access(filename, os.W_OK):
+                m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
+                    gtk.BUTTONS_CLOSE, _("The default learning tree is write protected in your install. This is normal. If you want to edit a learning tree, you have to select one of the trees stored in .solfege/learningtrees in your home directory."))
+                m.run()
+                m.destroy()
+    def _load_file(self, filename):
         self.m_tree = LearningTree(self.m_app.lessonfile_manager)
         # We use _m_orig_tree just to see if things has changed.
         self.m_filename = filename
