@@ -312,9 +312,13 @@ class MainWin(App, cfg.ConfigUtils):
                 assert loc == 'user'
                 self.m_tree.load(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
         except IOError:
+            if splash_win:
+                splash_win.hide()
             self.m_tree.load(self.default_learning_tree[1])
             self.set_list('app/learningtree', self.default_learning_tree)
             gu.dialog_ok(_("Learning tree '%s' not found. Using default tree." % filename))
+            if splash_win:
+                splash_win.show()
         self.create_practise_and_test_menu()
     def setup_menu(self):
         self.m_action_groups['Exit'].add_actions([
@@ -598,11 +602,7 @@ GNU General Public License for more details.""")
             loc, filename = self.get_list("app/learningtree")
         except ValueError:
             loc, filename = self.default_learning_tree
-        if loc == 'solfege':
-            win.load_file(filename)
-        else:
-            assert loc == 'user'
-            win.load_file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
+        win.load_file2(loc, filename)
         win.show()
     def post_constructor(self):
         global splash_win
