@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome, gobject
+import gtk, gobject
 import gu, inputwidgets
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget
 import abstract, const
@@ -27,16 +27,13 @@ import random
 class Teacher(abstract.MelodicIntervalTeacher):
     def __init__(self, exname, app):
         abstract.MelodicIntervalTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        self.lessonfileclass = lessonfile.IntervalsLessonfile
         self.m_statistics = statistics.IntervalStatistics(self)
         self.m_timeout_handle = None
         self.m_custom_mode = False
     def enter_test_mode(self):
         self.m_statistics.enter_test_mode()
-        count, t = lessonfile.parse_test_def(self.m_P.header.test)
-        self.m_test_questions = self.get_list('ask_for_intervals_0') * count
-        random.shuffle(self.m_test_questions)
-        self.m_test_idx = -1
+        self.m_P.enter_test_mode()
     def give_up(self):
         """This function is only called *after* the user already has
         answered wrong once, so the statistics are already updated.
@@ -81,7 +78,7 @@ class Gui(abstract.IntervalGui):
         self.g_mici = MultipleIntervalConfigWidget(self.m_exname)
         self.config_box.pack_start(self.g_mici, False, False)
         self.config_box.pack_start(gtk.HBox(), False,
-                                   padding=gnome.ui.PAD_SMALL)
+                                   padding=gu.PAD_SMALL)
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------
         self._create_select_inputwidget_gui()
@@ -145,7 +142,7 @@ class Gui(abstract.IntervalGui):
             return
         if mouse_button != 1:
             return
-        if self.m_t.m_app.m_test_mode and self.m_t.is_test_complete():
+        if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
             self.do_test_complete()
             return
         if self.m_t.m_app.m_test_mode and self.m_t.q_status == const.QSTATUS_NO:
@@ -255,6 +252,7 @@ class Gui(abstract.IntervalGui):
         else:
             self.m_t.m_statistics.reset_session()
             self.g_mici.hide()
+        self.g_statview.g_heading.set_text("%s - %s" % (_("Melodic interval"), self.m_t.m_P.header.title))
         self.g_new_interval.grab_focus()
         if self.m_t.m_app.m_test_mode:
             gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
