@@ -28,9 +28,9 @@ import utils
 import const
 import cfg
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.NameIntervalLessonfile
         self.m_answered_quality = None
         self.m_answered_number = None
@@ -58,8 +58,6 @@ class Teacher(abstract.LessonbasedTeacher):
         self.q_status = const.QSTATUS_NEW
         return True
     def get_music_string(self):
-        #return r"\staff{ \clef %(clef)s \stemUp %(high)s }" \
-        #    r"\addvoice{ \stemDown %(low)s"% {
         return r"\staff{ \clef %(clef)s \stemUp %(low)s %(high)s"% {
             'clef': self.m_P.header.clef,
             'high': (self.m_low_pitch + self.m_interval).get_octave_notename(),
@@ -143,7 +141,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_music_displayer.display(self.m_t.get_music_string(),
                     self.get_int('config/feta_font_size=20'))
             else:
-                self.g_win.display_error_message(_("Could not satisfy the constraints in the lesson header. The lesson file need to be adjusted."))
+                self.g_win.display_error_message2(_("Could not satisfy the constraints in the lesson header."), 'You must make more tones available by adjusting the "tones" variable in the lesson file header of the lesson file "%s".' % self.m_t.m_P.m_filename)
         except lessonfile.LessonfileException, e:
             self.g_win.display_exception_message(e, __file__)
     def on_interval_quality_clicked(self, button, n):
