@@ -22,10 +22,10 @@ import gu, const, soundcard, mpd, mpd.musicdisplayer
 import abstract, utils
 import lessonfile
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        abstract.Teacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.HeaderLessonfile
         self.m_question = None
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
