@@ -8,7 +8,7 @@ def get_page(name):
     print "downloading:", name
     u = urllib2.urlopen(wiki_url + "/" + name + "?skin=solfegedoc")
     s = u.read()
-    if s.find("Describe %s here" % upper(name.split("/")[1])) != -1:
+    if s.find("The page is missing") != -1:
         print "Page did not exist on the wiki."
         return None
     return s
